@@ -1,4 +1,4 @@
-from typing import Optional, List, Any
+from typing import Optional
 
 from pydantic import BaseModel
 
@@ -18,10 +18,10 @@ class ClientConfig(BaseModel):
       branch_name: string representing the branch name on which to commit. Defaults
         to the local active branch
     """
-    access_key: str
-    secret_key: str
+    access_key: Optional[str]
+    secret_key: Optional[str]
+    token: Optional[str]
     host: str
     workspace_id: str
-    local_repository_path: str
     repository_id: str
     branch_name: Optional[str]
